/* DO NOT EDIT! GENERATED AUTOMATICALLY! */
#if HAVE_WINSOCK2_H
# include <winsock2.h> /* avoid mingw pollution on DATADIR */
#endif
#define PREFIX "/cygdrive/c/software.b/gettext-0.21"
#define EXEC_PREFIX "/cygdrive/c/software.b/gettext-0.21"
#define BINDIR "/cygdrive/c/software.b/gettext-0.21/bin"
#define SBINDIR "/cygdrive/c/software.b/gettext-0.21/sbin"
#define LIBEXECDIR "/cygdrive/c/software.b/gettext-0.21/libexec"
#define DATAROOTDIR "/cygdrive/c/software.b/gettext-0.21/share"
#define DATADIR "/cygdrive/c/software.b/gettext-0.21/share"
#define SYSCONFDIR "/cygdrive/c/software.b/gettext-0.21/etc"
#define SHAREDSTATEDIR "/cygdrive/c/software.b/gettext-0.21/com"
#define LOCALSTATEDIR "/cygdrive/c/software.b/gettext-0.21/var"
#define RUNSTATEDIR "/cygdrive/c/software.b/gettext-0.21/var/run"
#define INCLUDEDIR "/cygdrive/c/software.b/gettext-0.21/include"
#define OLDINCLUDEDIR "/usr/include"
#define DOCDIR "/cygdrive/c/software.b/gettext-0.21/share/doc/gettext"
#define INFODIR "/cygdrive/c/software.b/gettext-0.21/share/info"
#define HTMLDIR "/cygdrive/c/software.b/gettext-0.21/share/doc/gettext"
#define DVIDIR "/cygdrive/c/software.b/gettext-0.21/share/doc/gettext"
#define PDFDIR "/cygdrive/c/software.b/gettext-0.21/share/doc/gettext"
#define PSDIR "/cygdrive/c/software.b/gettext-0.21/share/doc/gettext"
#define LIBDIR "/cygdrive/c/software.b/gettext-0.21/lib"
#define LISPDIR "/cygdrive/c/software.b/gettext-0.21/share/emacs/site-lisp"
#define LOCALEDIR "/cygdrive/c/software.b/gettext-0.21/share/locale"
#define MANDIR "/cygdrive/c/software.b/gettext-0.21/share/man"
#define PKGDATADIR "/cygdrive/c/software.b/gettext-0.21/share/gettext"
#define PKGINCLUDEDIR "/cygdrive/c/software.b/gettext-0.21/include/gettext-tools"
#define PKGLIBDIR "/cygdrive/c/software.b/gettext-0.21/lib/gettext-tools"
#define PKGLIBEXECDIR "/cygdrive/c/software.b/gettext-0.21/libexec/gettext-tools"
